@@ -73,7 +73,11 @@ class CLIPModel(nn.Module):
         with open(os.path.join(output_path, 'config.json'), 'w') as fOut:
             json.dump({'model_name': model_name, 'tokenizer_name': tokenizer_name}, fOut, indent=2)
 
-        self.model.save(os.path.join(output_path, model_name))
+        ## Save model
+        torch.save(self.model.state_dict(), os.path.join(output_path, model_name))
+
+        ##Save tokenizer
+        self.tokenizer.save(output_path)
 
     @staticmethod
     def load(input_path: str):
@@ -263,8 +267,9 @@ def tokenize(tokenizer, texts: Union[str, List[str]], context_length: int = 77)
     result = torch.zeros(len(all_tokens), context_length, dtype=torch.long)
 
     for i, tokens in enumerate(all_tokens):
-        if len(tokens) > context_length:
-            raise RuntimeError(f"Input {texts[i]} is too long for context length {context_length}")
+        tokens = tokens[0:context_length]
+        #if len(tokens) > context_length:
+        #    raise RuntimeError(f"Input {texts[i]} is too long for context length {context_length}")
         result[i, :len(tokens)] = torch.tensor(tokens)
 
     return result
